@@ -1,6 +1,6 @@
 package DBIx::Class::DeploymentHandler::HandlesDeploy;
 BEGIN {
-  $DBIx::Class::DeploymentHandler::HandlesDeploy::VERSION = '0.001000_09';
+  $DBIx::Class::DeploymentHandler::HandlesDeploy::VERSION = '0.001000_10';
 }
 use Moose::Role;
 
@@ -50,7 +50,10 @@ L<DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator::Deprecated>
 
 =head2 preinstall
 
- $dh->preinstall
+ $dh->preinstall({
+   version      => 1,
+   storage_type => 'SQLite'
+ });
 
 Run scripts before deploying to the database
 
@@ -62,27 +65,36 @@ Generate the needed data files to install the schema to the database.
 
 =head2 deploy
 
- $dh->deploy
+ $dh->deploy({ version => 1 })
 
 Deploy the schema to the database.
 
 =head2 prepare_resultsource_install
 
- $dh->prepare_resultsource_install($resultset->result_source)
+ $dh->prepare_resultsource_install({
+   result_source => $resultset->result_source,
+ })
 
 Takes a L<DBIx::Class::ResultSource> and generates a single migration file to
 create the resultsource's table.
 
 =head2 install_resultsource
 
- $dh->prepare_resultsource_install($resultset->result_source);
+ $dh->install_resultsource({
+   result_source => $resultset->result_source,
+   version       => 1,
+ })
 
 Takes a L<DBIx::Class::ResultSource> and runs a single migration file to
 deploy the resultsource's table.
 
 =head2 prepare_upgrade
 
- $dh->prepare_upgrade(1, 2, [1, 2]);
+ $dh->prepare_upgrade({
+   from_version => 1,
+   to_version   => 2,
+   version_set  => [1, 2]
+ });
 
 Takes two versions and a version set.  This basically is supposed to generate
 the needed C<SQL> to migrate up from the first version to the second version.
@@ -90,7 +102,11 @@ The version set uniquely identifies the migration.
 
 =head2 prepare_downgrade
 
- $dh->prepare_downgrade(2, 1, [1, 2]);
+ $dh->prepare_downgrade({
+   from_version => 1,
+   to_version   => 2,
+   version_set  => [1, 2]
+ });
 
 Takes two versions and a version set.  This basically is supposed to generate
 the needed C<SQL> to migrate down from the first version to the second version.
@@ -99,7 +115,9 @@ respective upgrade version set.
 
 =head2 upgrade_single_step
 
- my ($ddl, $sql) = @{$dh->upgrade_single_step($version_set)||[]}
+ my ($ddl, $sql) = @{
+   $dh->upgrade_single_step({ version_set => $version_set })
+ ||[]}
 
 Call a single upgrade migration.  Takes a version set as an argument.
 Optionally return C<< [ $ddl, $upgrade_sql ] >> where C<$ddl> is the DDL for
